## v9.0.6 (2024-09-15)

### Fix

- mistakenly included import of plottoolbox

### Refactor

- moved cli into it's own main function

## v9.0.5 (2024-06-21)

## v9.0.4 (2024-03-31)

## v9.0.3 (2023-12-16)

### Refactor

- sourcery refactor

## v9.0.2 (2023-08-08)

## v9.0.1 (2023-07-24)

## v9.0.0 (2023-02-13)

### Fix

- removed duplicate import of typing.Literal

## v8.0.3 (2023-02-13)

### Refactor

- small refactors

## v8.0.2 (2023-01-16)

## v8.0.1 (2023-01-07)

## v8.0.0 (2022-10-29)

### Fix

- move from typic to pydantic.validate_arguments

## v7.1.1 (2022-09-28)

### Refactor

- moved from tstoolbox.utils to toolbox_utils
- cleaned up code supporting id slices and indexing

## v7.1.0 (2022-08-14)

### Fix

- finishing touches on the id ranges within labels

### Feat

- implemented element ranges within labels

## v7.0.3 (2022-08-02)

### Fix

- **sort_columns**: fixed sort_columns keyword to sort when True and to leave alone if False

## v7.0.2 (2022-07-23)

### Fix

- several small fixes rolled, label, time-stamp, start_date/end_date, dump

## v7.0.1 (2022-07-09)

### Fix

- **extract**: fixed keywords in extract
- removed walrus operator so supports python 3.7

### Refactor

- removed __future__ and some addition f strings

## v7.0.0 (2022-02-14)

## v6.4.1 (2022-02-07)

### Refactor

- docsrc -> docs

## v6.3.1 (2021-08-01)

## v6.3.0 (2021-06-09)

## v6.2.0 (2021-05-12)

### Fix

- Use correct tstoolbox versions.
- Import the correct library name.

## v6.1.0 (2021-03-14)

## v6.0.0 (2020-09-07)

## v5.14.11.6 (2020-01-20)

## v5.13.11.6 (2020-01-14)

## v5.12.11.6 (2019-10-03)

## v4.10.11.5 (2019-06-22)
